import 'dart:async';

import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'method_channel_dyna_platform.dart';

/// The interface that platorm implementations of dyna must implement.
///
/// Platform implementations should extend this class rather than implement it
/// as `dyna` does not consider newly added methods to be breaking changes.
/// Extending this class (using `extends`) ensures that the subclass will get
/// the default implementation, while platform implementations that `implements`
/// this interface will be broken by newly added [DynaPlatform] methods.
abstract class DynaPlatform extends PlatformInterface {
  /// Constructs a DynaPlatform.
  DynaPlatform() : super(token: _token);

  static final Object _token = Object();

  static DynaPlatform _instance = MethodChannelDynaPlatform();

  /// The default instance of [DynaPlatform] to use.
  ///
  /// Defaults to [MethodChannelDynaPlatform].
  static DynaPlatform get instance => _instance;

  /// Platform-specific plugins should set this with their own platform-specific
  /// class that extends [DynaPlatform] when they register themselves.
  static set instance(DynaPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  /// Returns wallpaper-based colors from the platform.
  Future<List<int>?> getColors() {
    throw UnimplementedError('getColors() has not been implemented.');
  }
}
